##  Step 2: Add the Software Versions and Assess Risk and Suitability
The next step is to add software versions and make a risk and suitability assessment based on it.
  * Add software version information by leveraging information from the reference catalog. To learn more, see [IT Components in the Reference Catalog](https://help.sap.com/docs/leanix/ea/it-components-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "By using reference data for IT component fact sheets, you can increase standardization and data quality, set relations to other fact sheets for best-practice modeling, as well as manage technology obsolescence risks by using vendor lifecycle information.").
  * As a best practice, group IT components into standardized categories using the tech category fact sheet. For guidelines and best practices on modeling the tech category, see [Tech Category Modeling Guidelines](https://help.sap.com/docs/leanix/ea/tech-category-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model tech categories. This includes best practices and applicable use cases, and common antipatterns.").
  * Classify the IT component for phasing out or termination following the [Sunset model![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.techtarget.com%2Fwhatis%2Fdefinition%2Fsunsetting "https://www.techtarget.com/whatis/definition/sunsetting") using tags such as Candidate, Leading, Exception, and Sunset. Editing in the inventory table view mode is a convenient way to do this. To learn how to edit things in table view mode, see [Bulk Updating Data in Inventory Table View](https://help.sap.com/docs/leanix/ea/bulk-updating-data-in-inventory-table-view?locale=en-US&state=PRODUCTION&version=CLOUD "Table View lets you view and edit multiple fact sheets in a spreadsheet-like format—perfect for scanning, comparing, and updating data quickly and efficiently."). To learn more about using tags, see visit [Tags](https://help.sap.com/docs/leanix/ea/tags?locale=en-US&state=PRODUCTION&version=CLOUD "Tags are labels used to classify and categorize fact sheets, making it easy to filter, organize, and analyze data. Learn how to assign and manage tags, understand when and when not to use them, as well as leverage them for filtering and reporting.").
![Classifying the IT Components](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27577a807a4410148443ebe428444df3_LowRes.png)
Classifying the IT Components
